@@ -75,6 +75,10 @@ snowSuperLearner <- function(cluster, Y, X, newX = NULL, family = gaussian(), SL
 		stop("'family' not recognized")
 	}
 	
+	if (family$family != "binomial" & isTRUE("cvAUC" %in% method$require)){
+		stop("'method.AUC' is designed for the 'binomial' family only")
+	}
+	
   # create CV folds
 	validRows <- CVFolds(N = N, id = id, Y = Y, cvControl = cvControl)
 	
