@@ -1,5 +1,5 @@
 summary.CV.SuperLearner <- function(object, obsWeights = NULL, ...) {
-  method <- ifelse(is.null(as.list(object$call)[["method"]]), "method.NNLS", as.list(object$call)[["method"]])
+  method <- ifelse(is.null(as.list(object$call)[["method"]]), "method.NNLS", as.list(object$call)[["method"]])  # default is "method.NNLS"
 	library.names <- colnames(coef(object))
 	V <- object$V
 	n <- length(object$SL.predict)
@@ -20,14 +20,14 @@ summary.CV.SuperLearner <- function(object, obsWeights = NULL, ...) {
 	rownames(Risk.library) <- library.names
 	
 	# Risk estimate depends on the loss function used
-	if (method %in% c("method.NNLS", "method.NNLS2")) {
+	if (method %in% c("method.NNLS", "method.NNLS2", "method.CC_LS")) {
 		for (ii in seq_len(V)) {
 			Risk.SL[ii] <- mean(obsWeights[folds[[ii]]] * (Y[folds[[ii]]] - SL.predict[folds[[ii]]])^2)
 			Risk.dSL[ii] <- mean(obsWeights[folds[[ii]]] * (Y[folds[[ii]]] - discreteSL.predict[folds[[ii]]])^2)
 			Risk.library[, ii] <- apply(library.predict[folds[[ii]], , drop = FALSE], 2, function(x) mean(obsWeights[folds[[ii]]] * (Y[folds[[ii]]] - x)^2))	
 		}
 		se <- (1 / sqrt(n)) * c(sd(obsWeights * (Y - SL.predict)^2), sd(obsWeights * (Y - discreteSL.predict)^2), apply(library.predict, 2, function(x) sd(obsWeights * (Y - x)^2)))
-	} else if (method %in% c("method.NNloglik")) {
+	} else if (method %in% c("method.NNloglik", "method.CC_nloglik")) {
 		for (ii in seq_len(V)) {
 			Risk.SL[ii] <- -mean(obsWeights[folds[[ii]]] * ifelse(Y[folds[[ii]]], log(SL.predict[folds[[ii]]]), log(1 - SL.predict[folds[[ii]]])))
 			Risk.dSL[ii] <- -mean(obsWeights[folds[[ii]]] * ifelse(Y[folds[[ii]]], log(discreteSL.predict[folds[[ii]]]), log(1 - discreteSL.predict[folds[[ii]]])))
@@ -36,7 +36,16 @@ summary.CV.SuperLearner <- function(object, obsWeights = NULL, ...) {
 			})	
 		}
 		se <- rep.int(NA, (length(library.names) + 2))
-	} else {
+	} else if (method %in% c("method.AUC")) {
+		require("cvAUC") # make sure cvAUC loaded
+		require("ROCR")
+		for (ii in seq_len(V)) {
+			Risk.SL[ii] <- cvAUC(predictions = SL.predict[folds[[ii]]], labels = Y[folds[[ii]]], folds = NULL)$cvAUC
+			Risk.dSL[ii] <- cvAUC(predictions = discreteSL.predict[folds[[ii]]], labels = Y[folds[[ii]]], folds = NULL)$cvAUC
+			Risk.library[, ii] <- apply(library.predict[folds[[ii]], , drop = FALSE], 2, function(x) cvAUC(predictions = x, labels = Y[folds[[ii]]], folds = NULL)$cvAUC)
+		}
+		se <- rep.int(NA, (length(library.names) + 2)) # no se right now?
+		} else {
 		stop("summary function not available for SuperLearner with loss function/method used")
 	}
 	
@@ -49,10 +58,12 @@ summary.CV.SuperLearner <- function(object, obsWeights = NULL, ...) {
 print.summary.CV.SuperLearner <- function(x, digits = max(2, getOption("digits") - 2), ...) {
 	cat("\nCall: ", deparse(x$call, width.cutoff = .9*getOption("width")), "\n", fill = getOption("width"))
 	cat("Risk is based on: ")
-	if(x$method %in% c("method.NNLS", "method.NNLS2")) {
+	if(x$method %in% c("method.NNLS", "method.NNLS2", "method.CC_LS")) {
 		cat("Mean Squared Error")
-	} else if (x$method %in% c("method.NNLS")) {
+	} else if (x$method %in% c("method.NNLS", "method.CC_nloglik")) {
 		cat("Negative Log Likelihood (-2*log(L))")
+	} else if (x$method %in% c("method.AUC")) {
+		cat("Area under ROC curve (AUC)")
 	} else {
 		stop("summary method not available")
 	}
